@@ -15,9 +15,9 @@
 
     "use strict";
 
-	/*
-	 * helper functions
-	 */
+    /*
+     * helper functions
+     */
 
     // abbreviate at last blank before length and add "\u2026" (horizontal ellipsis)
     function abbreviateText(text, length) {
@@ -117,10 +117,21 @@
                     'display_name'      : 'Google+',
                     'referrer_track'    : '',
                     'language'          : 'en'
+                },
+                'linkedin' : {
+                    'status'            : 'on',
+                    'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/dummy_linkedin_en.png',
+                    'txt_info'          : '2 clicks for your privacy: Only if you click here the button will get active and you can send your recommendation to LinkedIn. An active button will send data do a third-party &ndash; more information on <em>i</em>.',
+                    'txt_linkedin_off'  : 'not connected to LinkedIn',
+                    'txt_linkedin_on'   : 'connected to LinkedIn',
+                    'perma_option'      : 'on',
+                    'display_name'      : 'LinkedIn',
+                    'referrer_track'    : '',
+                    'language'          : 'en'
                 }
             },
             'info_link'         : 'http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html',
-            'txt_help'          : 'Only if you activate the buttons, data will get sent to Facebook, Twitter or Google. This data might get stored in the USA. Get more information by clicking on <em>i</em>.',
+            'txt_help'          : 'Only if you activate the buttons, data will get sent to Facebook, Twitter, Google or LinkedIn. This data might get stored in the USA. Get more information by clicking on <em>i</em>.',
             'settings_perma'    : 'Activate buttons permanently:',
             'cookie_path'       : portal_url,
             'cookie_domain'     : document.location.host,
@@ -135,9 +146,10 @@
         var facebook_on = (options.services.facebook.status === 'on');
         var twitter_on  = (options.services.twitter.status  === 'on');
         var gplus_on    = (options.services.gplus.status    === 'on');
+        var linkedin_on = (options.services.linkedin.status === 'on');
 
         // check if at least one service is "on"
-        if (!facebook_on && !twitter_on && !gplus_on) {
+        if (!facebook_on && !twitter_on && !gplus_on && !linkedin_on) {
             return;
         }
 
@@ -222,7 +234,7 @@
                 var gplus_uri = uri + options.services.gplus.referrer_track;
 
                 // we use the Google+ "asynchronous" code, standard code is flaky if inserted into dom after load
-                var gplus_code = '<div class="g-plusone" data-size="medium" data-href="' + gplus_uri + '"></div><script type="text/javascript">window.___gcfg = {lang: "' + options.services.gplus.language + '"}; (function() { var po = document.createElement("script"); po.type = "text/javascript"; po.async = true; po.src = "https://apis.google.com/js/plusone.js"; var s = document.getElementsByTagName("script")[0]; s.parentNode.insertBefore(po, s); })(); </script>';
+                var gplus_code = '<div class="g-plusone" data-size="medium" data-annotation="bubble" data-href="' + gplus_uri + '"></div><script type="text/javascript">window.___gcfg = {lang: "' + options.services.gplus.language + '"}; (function() { var po = document.createElement("script"); po.type = "text/javascript"; po.async = true; po.src = "https://apis.google.com/js/plusone.js"; var s = document.getElementsByTagName("script")[0]; s.parentNode.insertBefore(po, s); })(); </script>';
                 var gplus_dummy_btn = '<img src="' + options.services.gplus.dummy_img + '" alt="&quot;Google+1&quot;-Dummy" class="gplus_one_dummy" />';
 
                 context.append('<li class="gplus help_info"><span class="info">' + options.services.gplus.txt_info + '</span><span class="switch off">' + options.services.gplus.txt_gplus_off + '</span><div class="gplusone dummy_btn">' + gplus_dummy_btn + '</div></li>');
@@ -242,6 +254,33 @@
                 });
             }
 
+            //
+            // LinkedIn
+            //
+            if (linkedin_on) {
+                var linkedin_enc_uri = encodeURIComponent(uri + options.services.linkedin.referrer_track);
+
+                var linkedin_code = '<script src="//platform.linkedin.com/in.js" type="text/javascript"></script><script type="IN/Share" data-counter="right"></script>';
+                var linkedin_dummy_btn = '<img src="' + options.services.linkedin.dummy_img + '" alt="&quot;LinkedIn&quot;-Dummy" class="linkedin_dummy" />';
+
+                context.append('<li class="linkedin help_info"><span class="info">' + options.services.linkedin.txt_info + '</span><span class="switch off">' + options.services.linkedin.txt_linkedin_off + '</span><div class="inshare dummy_btn">' + linkedin_dummy_btn + '</div></li>');
+
+                var $container_linkedin = $('li.linkedin', context);
+
+                $('li.linkedin div.inshare img,li.linkedin span.switch', context).live('click', function () {
+                    if ($container_linkedin.find('span.switch').hasClass('off')) {
+                        $container_linkedin.addClass('info_off');
+                        $container_linkedin.find('span.switch').addClass('on').removeClass('off').html(options.services.linkedin.txt_linkedin_on);
+                        $container_linkedin.find('img.linkedin_dummy').replaceWith(linkedin_code);
+                    } else {
+                        $container_linkedin.removeClass('info_off');
+                        $container_linkedin.find('span.switch').addClass('off').removeClass('on').html(options.services.linkedin.txt_linkedin_off);
+                        $container_linkedin.find('.inshare').html(linkedin_dummy_btn);
+                        window.IN = null;
+                    }
+                });
+            }
+
             //
             // Der Info/Settings-Bereich wird eingebunden
             //
@@ -264,12 +303,14 @@
             var facebook_perma = (options.services.facebook.perma_option === 'on');
             var twitter_perma  = (options.services.twitter.perma_option  === 'on');
             var gplus_perma    = (options.services.gplus.perma_option    === 'on');
+            var linkedin_perma = (options.services.linkedin.perma_option === 'on');
 
             // Menue zum dauerhaften Einblenden der aktiven Dienste via Cookie einbinden
             // Die IE7 wird hier ausgenommen, da er kein JSON kann und die Cookies hier ueber JSON-Struktur abgebildet werden
             if (((facebook_on && facebook_perma)
                 || (twitter_on && twitter_perma)
-                || (gplus_on && gplus_perma))
+                || (gplus_on && gplus_perma)
+                || (linkedin_on && linkedin_perma))
                     && (!$.browser.msie || ($.browser.msie && $.browser.version > 7.0))) {
 
                 // CUSTOM: Anfuerungszeichen vom Wert des Cookies entfernen
@@ -298,7 +339,7 @@
                 $container_settings_info.find('.settings_info_menu').removeClass('perma_option_off');
 
                 // Perma-Optionen-Icon (.settings) und Formular (noch versteckt) einbinden
-                $container_settings_info.find('.settings_info_menu').append('<span class="settings">Einstellungen</span><form><fieldset><legend>' + options.settings_perma + '</legend></fieldset></form>');
+                $container_settings_info.find('.settings_info_menu').append('<span class="settings">Settings</span><form><fieldset><legend>' + options.settings_perma + '</legend></fieldset></form>');
 
 
                 // Die Dienste mit <input> und <label>, sowie checked-Status laut Cookie, schreiben
@@ -330,6 +371,15 @@
                     );
                 }
 
+                if (linkedin_on && linkedin_perma) {
+                    var perma_status_linkedin = cookies.socialSharePrivacy_linkedin === 'perma_on' ? checked : '';
+                    $container_settings_info.find('form fieldset').append(
+                        '<input type="checkbox" name="perma_status_linkedin" id="perma_status_linkedin"'
+                            + perma_status_linkedin + ' /><label for="perma_status_linkedin">'
+                            + options.services.linkedin.display_name + '</label>'
+                    );
+                }
+
                 // Cursor auf Pointer setzen fuer das Zahnrad
                 $container_settings_info.find('span.settings').css('cursor', 'pointer');
 
@@ -369,6 +419,9 @@
                 if (gplus_on && gplus_perma && cookies.socialSharePrivacy_gplus === 'perma_on') {
                     $('li.gplus span.switch', context).click();
                 }
+                if (linkedin_on && linkedin_perma && cookies.socialSharePrivacy_linkedin === 'perma_on') {
+                    $('li.linkedin span.switch', context).click();
+                }
             }
         }); // this.each(function ()
     };      // $.fn.socialSharePrivacy = function (settings) {
